--------------------------------------------------------------------------------
--
-- Title       : Smart 577 FPGA
-- Design      : Main Board
-- Author      : Alex Shtengel
-- Company     : Home
--------------------------------------------------------------------------------
-- File        : PwmController.vhd
-- Generated   : Sep 14  2016
--------------------------------------------------------------------------------
-- Description : PWM Controller
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 14/09/16	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee ;

use ieee.std_logic_1164.all ;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity PwmController  is
GENERIC (ResolutionRange	: integer);
port
(
 ClockIn ,        																															-- General Clock
 nResetIn ,         																														-- General Reset active Low
 PmwClockIn            																													-- Pwm clock *  number (ResolutionRange +1) Bits
                    : in std_logic;

 PwmValueIn  																														        -- Port description
                    : in std_logic_vector(ResolutionRange downto 0);
 PwmOut,          																												  		-- PWM Output
 nPwmOut           																												  		-- not PWM Output
                    : out std_logic
);
end PwmController;

architecture  ArchPwmController of PwmController is

signal PwmClockRise,                                                            -- PWM Clock
 			 Pwm,          																												  	-- PWM Output
 			 nPwm           																												  -- not PWM Output

											: std_logic := '0';
signal PwmClockDevider,                                                         -- Counter for PWM clock generation
			 PulseLenghtCounter                                                       -- Count lenght of pulse
 											: std_logic_vector(ResolutionRange downto 0):= (others => '0');

begin

 PwmClockDevider_Process:
process (ClockIn)
variable DevideZero : std_logic_vector(ResolutionRange downto 0);
begin
 DevideZero := (others => '0');
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
	  PwmClockDevider <= (others => '1');                                         -- Counter for PWM clock generation
		PwmClockRise    <= '0';                                                     -- PWM Clock
	 when others =>
		case PmwClockIn is
		 when '1' =>
			if(PwmClockDevider = DevideZero) then
		 	 PwmClockDevider <= (others => '1');
			else
		 	 PwmClockDevider <= PwmClockDevider - 1;
			end if;
		 when others =>
		  PwmClockDevider <= PwmClockDevider;
		end case;
	 if(PwmClockDevider = DevideZero) then
		PwmClockRise    <= PmwClockIn;                                              -- PWM Clock
	 else
		PwmClockRise    <= '0';
	 end if;
	end case;
 end if;
end process  PwmClockDevider_Process;

 PulseLenghtCounter_Process:
process (ClockIn)
variable DevideZero : std_logic_vector(ResolutionRange downto 0);
begin
 DevideZero := (others => '0');
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
	  PulseLenghtCounter <= (others => '0');                                      -- Count lenght of pulse
		 Pwm <= '0';          																											-- PWM Output
 		nPwm <= '1';          																											-- not PWM Output
	 when others =>
		case PwmClockRise is
		 when '1' =>
		  PulseLenghtCounter <= PwmValueIn;
		 when others =>
			if(PulseLenghtCounter = DevideZero) then
			 PulseLenghtCounter <= (others => '0');
		 	 Pwm 	<= '0';          																										-- PWM Output
 		   nPwm <= '1';          																										-- not PWM Output
			else
		 	 Pwm  <= '1';          																										-- PWM Output
 		   nPwm <= '0';          																										-- not PWM Output
			 case PmwClockIn is
			  when '1' =>
				 PulseLenghtCounter <= PulseLenghtCounter - 1;
			  when others =>
			   PulseLenghtCounter <= PulseLenghtCounter;
			 end case;
			end if;
		end case;
	end case;
 end if;
end process  PulseLenghtCounter_Process;

 OutPut_Process:
process (ClockIn)
variable DevideZero : std_logic_vector(ResolutionRange downto 0):= (others => '0');
variable DevideFull : std_logic_vector(ResolutionRange downto 0):= (others => '1');
begin
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
		 PwmOut <= '0';          																										-- PWM Output
 		nPwmOut <= '1';          																										-- not PWM Output
	 when others =>
		if(PwmValueIn = DevideZero) then                                            -- 0%
		  PwmOut <= '0';          																									-- PWM Output
 		 nPwmOut <= '1';          																									-- not PWM Output
		elsif (PwmValueIn = DevideFull) then                                        -- 100 %
		  PwmOut <= '1';          																									-- PWM Output
 		 nPwmOut <= '0';          																									-- not PWM Output
		else
		  PwmOut <= Pwm;          																									-- PWM Output
 		 nPwmOut <= nPwm;          																									-- not PWM Output
		end if;
	end case;
 end if;
end process  OutPut_Process;
end ArchPwmController;

