--------------------------------------------------------------------------------
--
-- Title       : Smart 577 FPGA
-- Design      : Main Board
-- Author      : Alex Shtengel
-- Company     : Lumenis
--------------------------------------------------------------------------------
-- File        : PwmController.vhd
-- Generated   : Sep 14  2016
--------------------------------------------------------------------------------
-- Description : PWM Controller
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 14/09/16	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee ;

use ieee.std_logic_1164.all ;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity PwmController_Tb  is
end PwmController_Tb;

architecture  ArchPwmController_Tb of PwmController_Tb is
signal Clock       																 		 		 		 		 		 					-- Clock 30.000 MHz
										: std_logic := '0';
signal PmwClock        																													-- 100 kHz for Pwm clock ~ 100 Hz
										: std_logic := '0';

signal nClock,                                                                  -- not Clock 30.000 MHz
			 PmwBasicClock,                                            								-- PWM basic clock rise
			 nReset,         																													-- General Reset active Low
			 PWM,          																														-- PWM Output
			 nPWM   																																	-- not PWM Output
										: std_logic;
signal PwmValue
										: std_logic_vector(9 downto 0);

begin
Clock 		<= not Clock after 16.667 nS;     																		-- Clock 30.000 MHz
nClock 		<= not Clock ;     																										-- not Clock 30.000 MHz
nReset		<= '1','0' after 50 nS,'1' after 100 nS;         											-- General Reset active Low
PmwClock  <= not PmwClock after 0.5 uS;     																				-- 100 kHz for Pwm clock ~ 1000 Hz

PmwBasicClock_Inst : entity work.DigDef
port map
(
 ClockIn 			=> Clock,      																										-- General Clock
 nClockIn			=> nClock,
 nResetIn			=> nReset,																												-- General Reset active low
 InputSignal	=> PmwClock,
 RiseOutput		=> PmwBasicClock,                                            			-- PWM basic clock rise
 FallOutput   => open
);

PwmController_UUT : entity work.PwmController
-- (ResolutionRange	: integer);
GENERIC MAP(9)
port map
(
 ClockIn 				=> Clock,        																								-- General Clock
 nResetIn 			=> nReset,         																							-- General Reset active Low
 PmwClockIn     => PmwBasicClock,       																				-- Pwm clock *  number (ResolutionRange +1) Bits
 PwmValueIn			=> PwmValue,																										-- Port description
 PwmOut					=> PWM,          																								-- PWM Output
 nPwmOut        => nPWM   																											-- not PWM Output
);

 TestProcess:
process
begin
 PwmValue <= "00" & X"55";																											-- Port description
wait for	5 mS;
 PwmValue <= "01" & X"55";																											-- Port description
wait for	5 mS;
 PwmValue <= "11" & X"55";																											-- Port description
wait for	5 mS;
 PwmValue <= "11" & X"FF";																											-- Port description
wait for	5 mS;
 PwmValue <= "00" & X"00";																											-- Port description

wait;
end process  TestProcess;

end ArchPwmController_Tb;
